.. _badges:

.. image:: https://travis-ci.org/avanov/frameapp.svg?branch=develop
    :target: https://travis-ci.org/avanov/frameapp

.. image:: https://coveralls.io/repos/github/avanov/frameapp/badge.svg?branch=develop
    :target: https://coveralls.io/github/avanov/frameapp?branch=develop

.. image:: https://requires.io/github/avanov/frameapp/requirements.svg?branch=develop
    :target: https://requires.io/github/avanov/frameapp/requirements/?branch=develop
    :alt: Requirements Status

.. image:: https://readthedocs.org/projects/frameapp/badge/?version=develop
    :target: http://frameapp.readthedocs.org/en/develop/
    :alt: Documentation Status

.. image:: http://img.shields.io/pypi/v/frameapp.svg
    :target: https://pypi.python.org/pypi/frameapp
    :alt: Latest PyPI Release


=========
Frameapp
=========

Frameapp provides primitives for consistent application initialization.
